<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.systemmonitor.systemserver.set!message" line="0"/>
			<source>Authentication is required to set service startup type</source>
			<translation>Bạn cần xác thực để thiết lập loại khởi động dịch vụ</translation>
		</message>
		<message>
			<location filename="org.deepin.systemmonitor.systemserver.set!description" line="0"/>
			<source>Set service startup type</source>
			<translation>Thiết lập loại khởi động dịch vụ</translation>
		</message>
	</context>
</TS>